@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2010-2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2010-2018 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -83,8 +83,8 @@ void Ldap::create()
 
     basedn.replace(QLatin1Char('.'), QStringLiteral(",dc="));
 
-    if (!basedn.startsWith(QStringLiteral("dc="))) {
-        basedn.prepend(QStringLiteral("dc="));
+    if (!basedn.startsWith(QLatin1String("dc="))) {
+        basedn.prepend(QLatin1String("dc="));
     }
 
     // Set the changes
